## 每日成交持仓排名

接口：fut_holding

描述：获取每日成交持仓排名数据

限量：单次最大2000，总量不限制

积分：用户需要至少2000积分才可以调取，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | N | 交易日期 （trade_date/symbol至少输入一个参数） |
| symbol | str | N | 合约或产品代码 |
| start_date | str | N | 开始日期(YYYYMMDD格式，下同) |
| end_date | str | N | 结束日期 |
| exchange | str | N | 交易所代码 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | Y | 交易日期 |
| symbol | str | Y | 合约代码或类型 |
| broker | str | Y | 期货公司会员简称 |
| vol | int | Y | 成交量 |
| vol_chg | int | Y | 成交量变化 |
| long_hld | int | Y | 持买仓量 |
| long_chg | int | Y | 持买仓量变化 |
| short_hld | int | Y | 持卖仓量 |
| short_chg | int | Y | 持卖仓量变化 |
| exchange | str | N | 交易所 |

接口示例

```python
pro = ts.pro_api()

df = pro.fut_holding(trade_date='20181113', symbol='C1905', exchange='DCE')
```

数据示例

```python
trade_date symbol  broker       vol    vol_chg  long_hld    long_chg  \
0    20181113      C    东证期货   37161.0   -6435.0   15432.0    1837.0   
```